<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define( 'THEMEROOT', get_stylesheet_directory_uri() );
define( 'IMAGES', THEMEROOT . '/images' );
define( 'SCRIPTS', THEMEROOT . '/js' );
require_once( 'wp_bootstrap_navwalker.php' );


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_setup' ) ) {
	function alpha_setup() {
		/**
		 * Make the theme available for translation.
		 */
		$lang_dir = THEMEROOT . '/languages';
		load_theme_textdomain( 'alpha', $lang_dir );

		/**
		 * Add support for post formats.
		 */
//		add_theme_support( 'post-formats',
//			array(
//				'gallery',
//				'link',
//				'image',
//				'quote',
//				'video',
//				'audio'
//			)
//		);

		/**
		 * Add support for automatic feed links.
		 */
        add_theme_support('html5');
        add_theme_support('widgets');
        add_theme_support('automatic-feed-links');
        add_theme_support('widgets');
        add_theme_support('post-thumbnails');
        add_theme_support('category-thumbnails');
        add_theme_support('yoast-seo-breadcrumbs');
        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-slider');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');


		/**
		 * Register nav menus.
		 */
		register_nav_menus(
			array(
				'main-menu' => __( 'القائمة الرئيسية', 'alpha' ),
//				'footer'   => __( 'قائمة الفوتر ', 'alpha' )
			)
		);
	}

	add_action( 'after_setup_theme', 'alpha_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_scripts' ) ) {
	function alpha_scripts() {
		// Adds support for pages with threaded comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register scripts
		wp_register_script( 'popper', SCRIPTS . '/popper.js', array( 'jquery' ), false, true );
		wp_register_script( 'bootstrap-js', SCRIPTS . '/bootstrap-rtl.js', array( 'jquery' ), false, true );
		wp_register_script( 'slick', 'https://cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'fancybox', 'https://cdn.jsdelivr.net/gh/fancyapps/fancybox@3.5.7/dist/jquery.fancybox.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'owlcarousel', SCRIPTS . '/owl.carousel.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'wow', SCRIPTS . '/wow.min.js', array( 'jquery' ), false, true );


		// Load the custom scripts
		wp_enqueue_script( 'popper' );
		wp_enqueue_script( 'bootstrap-js' );
		wp_enqueue_script( 'slick' );
		wp_enqueue_script( 'fancybox' );
//		wp_enqueue_script( 'owlcarousel' );
		wp_enqueue_script( 'wow' );
		if ( ! is_rtl() ) {
			wp_register_script( 'custom', SCRIPTS . '/custom.js', array( 'jquery' ), false, true );
			wp_enqueue_script( 'custom' );

		} else {
			wp_register_script( 'custom-rtl', SCRIPTS . '/custom-rtl.js', array( 'jquery' ), false, true );
			wp_enqueue_script( 'custom-rtl' );

		}
		// Load the stylesheets

		wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
		wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
		wp_enqueue_style( 'slick',   'https://cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.css' );
		wp_enqueue_style( 'fancybox',   'https://cdn.jsdelivr.net/gh/fancyapps/fancybox@3.5.7/dist/jquery.fancybox.min.css' );
		wp_enqueue_style( 'woo-custom', THEMEROOT . '/woo.css' );

		if ( is_rtl() ) {

			wp_enqueue_style( 'bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.css' );
			wp_enqueue_style( 'rtl', THEMEROOT . '/style.css' );

		} else {
            wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
			wp_enqueue_style( 'en', THEMEROOT . '/en.css' );
		}

	}

	add_action( 'wp_enqueue_scripts', 'alpha_scripts' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */


/*************************************************/
/* Register Taxonami */
/*************************************************/
//add_action( 'init', 'create_sections' );
//
//function create_sections() {
//	register_taxonomy(
//		'sections',
//		'car-parts',
//		array(
//			'label'             => __( 'تصنيفات المنتجات' ),
//			'hierarchical'      => true,
//			'show_ui'           => true,
//			'show_admin_column' => true,
//			'show_in_nav_menus' => true,
//			'show_tagcloud'     => true,
//			'public'            => true
//		)
//
//	);
//
//}
//register_taxonomy(
//	'sections-tags',
//	'car-parts',
//	array(
//		'hierarchical'  => false,
//		'label'         => __( 'Tags'),
//		'singular_name' => __( 'Tag' ),
//		'rewrite'       => true,
//		'query_var'     => true
//	)
//);
register_post_type( 'slider', array(
	'public'              => true,
	'hierarchical'        => false,
	'exclude_from_search' => false,
	'has_archive'         => false,
	'rewrite'             => array( 'slug' => 'slider' ),
	'capability_type'     => 'post',
	'taxonomies'          => array( 'post_tag' ),
	'labels'              => array(
		'name'               => 'السلايدر',
		'add_new_item'       => 'إضافة سلايدر',
		'singular_name'      => 'السلايدر',
		'menu_name'          => 'السلايدر',
		'name_admin_bar'     => 'سلايدر',
		'all_items'          => 'كافة السلايدر',
		'add_new'            => 'إضافة سلايدر',
		'edit_item'          => 'تحرير السلايدر',
		'new_item'           => 'سلايدر جديدة',
		'view_item'          => 'مشاهدة السلايدر',
		'search_items'       => 'البحث عن سلايدر',
		'not_found'          => 'لا يوجد سلايدرات.',
		'not_found_in_trash' => 'لا يوجد سلايدرات',
		'parent_item_colon'  => 'القسم الرئيسى'
	),
	'supports'            => array( 'title', 'thumbnail', 'editor' )
) );


//add_image_size( 'small', 100, 100 );


/*************************************************/
/* Page Option */
/*************************************************/
if ( function_exists( 'acf_add_options_page' ) ) {

	acf_add_options_page( array(
		'page_title'    => 'اعدادات القالب',
		'menu_title'    => 'اعدادات القالب',
		'menu_slug'     => 'theme-general-settings',
		'capability'    => 'edit_posts',
		'update_button' => 'حفظ الاعدادات',
		'redirect'      => false
	) );


}

function mytheme_admin_bar_render() {
	global $wp_admin_bar;
	$wp_admin_bar->add_menu( array(
		'id'    => 'themeoptions',
		'title' => '<i class="options-icon"></i>' . __( 'اعدادات القالب', 'alpha' ),
		'href'  => admin_url( 'admin.php?page=theme-general-settings' ),
		'icon'  => 'img'
	) );
}

// and we hook our function via
add_action( 'wp_before_admin_bar_render', 'mytheme_admin_bar_render' );



/**
 * Show cart contents / total Ajax
 */
add_filter( 'woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment' );

function woocommerce_header_add_to_cart_fragment( $fragments ) {
    global $woocommerce;

    ob_start();

    ?>
    <span class="header-cart xoo-wsc-basket"><i class="fa fa-shopping-basket"></i> <?php echo sprintf(_n('%d Products', '%d Products', WC()->cart->get_cart_contents_count()), WC()->cart->get_cart_contents_count()); ?> - <?php echo WC()->cart->get_cart_total(); ?></span>
    <?php
    $fragments['span.header-cart'] = ob_get_clean();
    return $fragments;
}

/*************************************************/
/* Sidebar */
/*************************************************/
if (function_exists('register_sidebar')) {
    register_sidebar(
        array(
            'name' => 'sidebar',
            'id' => 'sidebar',
            'description' => 'Sidebar',
            'before_widget' => '<div class="rest-of-news">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="sub-cats-title woocommerce-info">',
            'after_title' => '</h4>'

        )
    );
    register_sidebar(
        array(
            'name' => 'sidebar primary',
            'id' => 'primary',
            'description' => 'Sidebar primary',
            'before_widget' => '<div class="box-section">',
            'after_widget' => '</div>',
            'before_title' => '<h5 class="box-section-title">',
            'after_title' => '</h5>'

        )
    );
}


//function remove_from_admin_bar($wp_admin_bar) {

//    $wp_admin_bar->remove_node('updates');
//    $wp_admin_bar->remove_node('comments');
//    $wp_admin_bar->remove_node('new-content');
//    $wp_admin_bar->remove_node('ubermenu');
//    //$wp_admin_bar->remove_node('site-name');
//    //$wp_admin_bar->remove_node('my-account');
//    //$wp_admin_bar->remove_node('search');
//    $wp_admin_bar->remove_node('customize');
//    $wp_admin_bar->remove_node('wp-logo');
//}
//add_action('admin_bar_menu', 'remove_from_admin_bar', 999);